# homeslice

dotfiles and :pizza: management

[![image][homesick_pypi]][homesick_pypi_web] [![image][homesick_license]][homesick_license_web]

Homeslice is originally based on [pyhome][pyhome] by Andrew Crozier.

## TODO 

This is a simple python utility with similar functionality to the
functionality of the [`homesick`][homesick] ruby utility, providing a simple
interface for managing dotfiles via git repositories.

This port exists because I wanted an easier to extend version of [homesick][homesick] and [pyhome][pyhome].

[homesick]: https://github.com/technicalpickles/homesick
[homesick_license]: http://img.shields.io/badge/license-MIT-green.svg
[homesick_license_web]: https://github.com/jefftriplett/homeslice/blob/master/LICENSE
[homesick_pypi]: http://img.shields.io/pypi/v/homeslice.svg
[homesick_pypi_web]: https://pypi.python.org/pypi/homeslice
[pyhome]: https://github.com/acroz/pyhome
